//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function qp = %Quat_p_s(q, p)
    // Raise quaternion to integer power
    //
    // Description
    // <literal>Q^N</literal> is the quaternion Q raised to the integer power N.
    //
    // Notes:
    // - Overloaded operator '^'
    // - Computed by repeated multiplication.
    //
    // See also 
    // Quaternion
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014 - Davide Cappucci

    // check that exponent is an integer
    if (p - floor(p)) ~= 0
        error('quaternion exponent must be integer');
    end

    qp = q;

    // multiply by itself so many times
    for i = 2:abs(p)
        qp = qp * q;
    end

    // if exponent was negative, invert it
    if p<0
        qp = qinv(qp);
    end
endfunction
