//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function v = %Robot_e(field, l)
    v = [];
    if typeof(l)=="Robot" then
        select convstr(field,"l")
        case "plot" then
            if ~isempty(l.q) then
                v = l.q;
            else
                warning("Undefined joint pose.");
                v= zeros(1,l.n)
            end
        case "plot_robot" then
            if ~isempty(l.q) then
                v = l.q;
            else
                warning("Undefined joint pose.");
                v= zeros(1,l.n)
            end
        case "rp" then
            v =RP(l);
        case "teach" then
            v = teach(l);
        case "isspherical" then
            v = isspherical(l);
        case "dyn" then
            dyn(l);
        case "islimit" then
            error("Use ''islimit(robot,q)''");

        case "fkine" then
            error("Use ''fkine(robot,q)''");
        case "ikine6s" then
            error("Use ''ikine6s(robot,T)''");
        case "ikine3" then
            error("Use ''ikine3(robot,T)''");
        case "ikine" then
            error("Use ''ikine(robot,T)''");
        case "jacob0" then
            error("Use ''jacob0(robot,Q)''");
        case "jacobn" then
            error("Use ''jacobn(robot,Q)''");
        case "maniplty" then
            error("Use ''maniplty(robot,Q)''");
        case "accel" then
            error("Use ''accel(robot, Q, QD, TORQUE)''");
        case "coriolis" then
            error("Use ''coriolis(robot, Q, QD)''");
        case "fdyn" then
            error("Use ''fdyn(robot, T, TORQFUN)''");
        case "friction" then
            error("Use ''friction(robot, QD)''");
        case "gravload" then
            error("Use ''gravload(robot, Q)''");
        case "inertia" then
            error("Use ''inertia(robot, Q)''");
        case "nofriction" then
            v = nofriction(l);
            warning("Options will not considered, use ''nofriction(robot,options)''");
        case "rne" then
            error("Use ''rne(robot, Q, QD, QDD)''");
        case "payload" then
            error("Use ''payload(robot, M, P)''");
        case "perturb" then
            v = perturb(l);
            warning("Options will not considered, default P=10%. Use ''perturb(robot,P)''");
        else
            error('Invalid field');
            v=[];
        end
    end
endfunction
