//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function %Robot_p(r)
    rp = [];
    for i = 1:r.n,
        rp = [rp r.links(i).RP];
    end

    //informational line
    if r.mdh
        convention = 'modDH';
    else
        convention = 'stdDH';
    end

    printf("%s (%d axis, %s, %s)", r.name, r.n, strcat(rp),convention);

    // comment and other info
    if ~isempty(r.manuf) then
        printf(" [%s]", r.manuf);
    end

    if ~isempty(r.comment) then
        printf(" \n%s", r.comment);
    end
    printf("\n+---+-----------+---------------+---------------+---------------+");
    printf("\n| j |  alpha\t|      a  \t|    theta\t|       d  \t|");
    printf("\n+---+-----------+---------------+---------------+---------------+\n");
    for i = 1:r.n,
        if r.links(i).sigma == 0 then
            mprintf('| %d |  %.4f\t|    %.4f\t|     q%d   \t|     %.4f\t|\n',i,r.links(i).alpha,r.links(i).a,i,r.links(i).d);
        else
        mprintf('| %d |  %.4f\t|    %.4f\t|     %.4f\t|     d%d   \t|\n',i,r.links(i).alpha,r.links(i).a,r.links(i).theta,i);
        end
        
    end
    printf("+---+-----------+---------------+---------------+---------------+\n");
    
    printf("\n grav = | %.2f |   base = | %.2f %.2f %.2f %.2f |   tool = | %.2f %.2f %.2f %.2f |",r.gravity(1),r.base(1,:),r.tool(1,:));
    printf("\n        | %.2f |          | %.2f %.2f %.2f %.2f |          | %.2f %.2f %.2f %.2f |",r.gravity(2),r.base(2,:),r.tool(2,:));
    printf("\n        | %.2f |          | %.2f %.2f %.2f %.2f |          | %.2f %.2f %.2f %.2f |",r.gravity(3),r.base(3,:),r.tool(3,:));
    printf("\n                          | %.2f %.2f %.2f %.2f |          | %.2f %.2f %.2f %.2f |",r.base(4,:),r.tool(4,:));
 
endfunction
