//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function e = %l_o_Quat(q1, q2)
    // Test quaternion equality
    //
    // Description
    // <literal>Q1==Q2</literal> is true if the quaternions Q1 and Q2 are equal.
    //
    // Notes:
    // - Overloaded operator '=='.
    // - Note that for unit Quaternions Q and -Q are the equivalent
    //   rotation, so non-equality does not mean rotations are not
    //   equivalent.
    // - If Q1 is a list of quaternions, each element is compared to 
    //   Q2 and the result is a logical array of the same length as Q1.
    // - If Q2 is a list of quaternions, each element is compared to 
    //   Q1 and the result is a logical array of the same length as Q2.
    //
    // See also 
    // Quaternion
    // %Quat_n_Quat
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014 - Davide Cappucci
    if (length(q2) == 3) & (length(q1) > 1)
        for i=1:length(q1)
            e(i) = (q1(i) == q2);
        end
    else
        error('quaternion:badargs');
    end
endfunction
