//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

// Scilab ( http://www.scilab.org/ ) 
// This file is part of Scilab 5.5.0-beta-1
// Copyright (C) 2013 - Scilab Enterprises - Charlotte HECQUET

function c=cross(a,b)
    // This function returns the cross product of a and b
    rhs = argn(2);
    if rhs <> 2 then
        error(msprintf(_("%s: Wrong number of input arguments: %d expected.\n"), "cross",2));
    end
    if type(a) > 8 | type(a) == 6 then
        error(msprintf(_("%s: Wrong type for input argument #%d: A real, complex, boolean or polynomial matrix expected.\n"), "cross", 1));
    end
    if type(b) > 8 | type(b) == 6 then
        error(msprintf(_("%s: Wrong type for input argument #%d: A real, complex, boolean or polynomial matrix expected.\n"), "cross", 2));
    end
    if (size(a,1) <> size(b,1) | size(a,2)<>size(b,2)) then
        error(msprintf(_("%s: Wrong size for input arguments: Same sizes expected.\n"), "cross"));
    end
    if (size(a,1)<>1 | size(a,2)<>3) & size(a,1)<>3 then
        error(msprintf(_("%s: Wrong size for input argument #%d: A matrix of size 1x3 or 3xN expected.\n"), "cross", 1));
    end

    if size(a,2)==3 & size(a,1)==1 then
        c=a(:,[2 3 1]).*b(:,[3 1 2]) - a(:,[3 1 2]).*b(:,[2 3 1]);
    else
        c=a([2 3 1],:).*b([3 1 2],:) - a([3 1 2],:).*b([2 3 1],:);
    end
endfunction
