//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function T = eul2tr(phi, varargin)
// Euler angles to homogeneous transform
//
// Calling Sequence
// TR = EUL2TR(PHI, THETA, PSI, OPTIONS)
// TR = EUL2TR(EUL, OPTIONS)
//
//  Parameters
//  OPTIONS,'deg'     : Compute angles in degrees (radians default)
//
// Description
// T = EUL2TR(PHI, THETA, PSI, OPTIONS) is a homogeneous transformation
// equivalent to the specified Euler angles.  These correspond to rotations 
// about the Z, Y, Z axes respectively. If PHI, THETA, PSI are column vectors 
// then they are assumed to represent a trajectory and R is a three dimensional 
// matrix, where the last index corresponds to rows of PHI, THETA, PSI.
//
// T = EUL2TR(EUL, OPTIONS) as above but the Euler angles are taken from
// consecutive columns of the passed matrix EUL = [PHI THETA PSI].
//
// <refsection>
// <title>Notes</title>
// <itemizedlist>
// <listitem><para>The vectors PHI, THETA, PSI must be of the same length.</para></listitem>
// <listitem><para>The translational part is zero.</para></listitem>
// </itemizedlist>
// </refsection>
//
// See also 
// eul2r
// rpy2tr
// tr2eul
//
// Authors
// Copyright (C) 1993-2011 - Peter I. Corke
// Copyright (C) 2014 - Davide Cappucci

    R = eul2r(phi, varargin(:));
    T = r2t(R);

endfunction
