//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function xd = fdyn2(t, x, robot, torqfun, varargin)
//  private function called by FDYN
//
//  Calling Sequence
//   XDD = FDYN2(T, X, FLAG, ROBOT, TORQUEFUN)
//
// Description
// Called by FDYN to evaluate the robot velocity and acceleration for
// forward dynamics.  T is the current time, <literal>X = [Q QD]</literal> is the state vector,
// ROBOT is the object being integrated, and TORQUEFUN is the string name of
// the function to compute joint torques and called as
//
//      <literal> TAU = TORQUEFUN(T, X)</literal>
//
// if not given zero joint torques are assumed.
//
// The result is <literal>XDD = [QD QDD]</literal>.
//
// See Also
// fdyn
//
// Authors
// Copyright (C) 1993-2011 - Peter I. Corke
// Copyright (C) 2014 - Davide Cappucci

//
// This file is part of The Robotics Toolbox for Matlab (RTB).
//

    n = robot.n;

    q = x(1:n)';
    qd = x(n+1:2*n)';

    // evaluate the torque function if one is given
    if type(torqfun)==13 then   // 'function_handle'
        tau = torqfun(robot, t, q, qd, varargin(:));
    else
        tau = zeros(1,n);
    end
    
    qdd = accel(robot,x(1:n,1)', x(n+1:2*n,1)', tau);
    xd = [x(n+1:2*n,1); qdd];
endfunction
