//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function h = isrot(r)
    // Test if argument is a rotation matrix
    //
    // Calling Sequence
    // isrot(R)
    // isrot(R, "valid")
    //
    // Description
    // ISROT(R) is true (1) if the argument is of dimension 3x3 or 3x3xN, else false (0).
    //
    // ISROT(R, "valid") as above, but also checks the validity of the rotation
    // matrix.
    //
    // <refsection>
    // <title>Notes</title>
    // <itemizedlist>
    // <listitem><para>A valid rotation matrix has determinant of 1.</para></listitem>
    // </itemizedlist>
    // </refsection>
    //
    // See also 
    // ishomog
    // isvec
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014 - Davide Cappucci
    
    [%nargout,%nargin] = argn(0);

    d = size(r);
    if ndims(r) >= 2
        h =  and(d(1:2) == [3 3]);

        if (h & %nargin > 1) then
            h = abs(det(r) - 1) < %eps;
        end

    else
        h = %f;
    end
endfunction

