//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function v = isspherical(r)
    // Test for spherical wrist
    //
    // Calling Sequence
    // R.isspherical()
    //
    // Description
    // R.isspherical() is true if the robot has a spherical wrist, that is, the 
    // last 3 axes are revolute and their axes intersect at a point.
    //
    // See also
    // SerialLink
    // ikine6s 
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014 - Davide Cappucci

    L = list(r.links(length(r.links)-2:length(r.links)));
    v= %f;
    // first test that all lengths are zero
    if ~and( [L(1).a L(2).a L(3).a L(2).d L(3).d] == 0 ) then
        return;
    end
    if ((abs(L(1).alpha) == %pi/2) & (abs(L(1).alpha + L(2).alpha)) < %eps) then
        v = %t;
    else
        v = %f;
    end

endfunction
