//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function r2 = mtimes(r, l)
    // Concatenate robots
    //
    // Calling Sequence
    // R = R1 * R2 
    // R = R1 * LINK
    // R = mtimes(R1,R2)
    // 
    // Description
    // R = R1 * R2 (or R = mtimes(R1,R2)) is a robot object that is equivalent 
    // to mechanically attaching robot R2 to the end of robot R1.
    // It is possible to attach a single link to the robot using R = R1 * LINK.
    //
        // <refsection>
    // <title>Notes</title>
    //  <itemizedlist>
    // <listitem><para>If R1 has a tool transform or R2 has a base transform these are 
    //   discarded since DH convention does not allow for arbitrary intermediate
    //   transformations.</para></listitem>
    // </itemizedlist>
	// </refsection>
    //
    // See also 
    // SerialLink
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014 - Davide Cappucci

    if l(1)(1)== 'Robot' then
        r2 = SerialLink(lstcat(r.links,l.links));
        r2.base = r.base;
    elseif  l(1)(1) ==  'Link' then
        r2 = SerialLink(lstcat(r.links,list(l)));
    end
endfunction
