//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function print_link(L)
// Display parameters of link
//
// Description
// L.print_link() displays the link parameters in compact single line format.  If L is a
// vector of Link objects displays one line per element.
//
// <refsection>
// <title>Notes</title>
// <itemizedlist>
//  <listitem><para> This method is invoked implicitly at the command line when the result
//   of an expression is a Link object and the command has no trailing
//   semicolon.</para></listitem>
// </itemizedlist>
//</refsection>  
//
// See also
//  Link
//	SerialLink 
//  dyn
//
// Authors
// Copyright (C) 1993-2011 - Peter I. Corke
// Copyright (C) 2014 - Davide Cappucci;

    if typeof(L)== 'Link' then
        if (L(7)==1) then 
            mdh = "modDH";
        else
            mdh = "stdDH";
        end

        if (L(6)==0) then 
            linktype = "R";
            mprintf("alpha=%3.4f,\ta=%3.4f,\ttheta=q,\td=%3.4f,\t(%s, %s)\n", L.alpha, L.a, L.d, linktype, mdh);
        else
            linktype = "P";
            mprintf("alpha=%3.4f,\ta=%3.4f,\ttheta=%3.4f,\td=d,\t\t(%s, %s)\n", L.alpha, L.a, L.theta, linktype, mdh);
        end
        
    elseif (typeof(L)=='Robot' | typeof(L)=='list') 
        if typeof(L)=='list' then
            n = length(L);
            for i=1:n,
                print_link(L(i));
            end
        else
            links = L.links;
            print_link(links);
        end
    else
        error('print_link:badarg');
    end
endfunction
