//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function J = rpy2jac(r, p, y)
    // Jacobian from RPY angle rates to angular velocity
    //
    // Calling Sequence
    //  J = rpy2jac(EUL)
    //  J = rpy2jac(R, P, Y) 
    //
    // Description
    // J = RPY2JAC(EUL) is a Jacobian matrix (3x3) that maps roll-pitch-yaw angle 
    // rates to angular velocity at the operating point RPY=[R,P,Y].
    //
    // J = RPY2JAC(R, P, Y) as above but the roll-pitch-yaw angles are passed
    // as separate arguments.
    //
    // <refsection>
	// <title>Notes</title>
	// <itemizedlist>
    // <listitem><para> Used in the creation of an analytical Jacobian.</para></listitem>
    // </itemizedlist>
	// </refsection>
    //
    // See also 
    // eul2jac
    // jacobn
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014 - Davide Cappucci


    [%nargout,%nargin] = argn(0);
    if length(r) == 3
        // rpy2jac([r,p,y])
        p = r(2);
        y = r(3);
        r = r(1);
    elseif %nargin ~= 3
        error('rpy2jac: bad arguments');
    end
    J = [	
    1  0       sin(p)
    0  cos(r)  -cos(p)*sin(r)
    0  sin(r)  cos(p)*cos(r)
    ];
endfunction
