//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function R = skew(w)
    //  Generates a skew-symmetric matrix
    //
    //  Calling Sequence
    //	R = SKEW(w)
    //
    //  Description
    //  Generates a skew-symmetric matrix given a vector w
    //
    // Bibliography
    //
    // Authors
    // Copyright (C) 2005, by Brad Kratochvil
    // Copyright (C) 2014 - Davide Cappucci

	    // [1] http://www.mathworks.com/matlabcentral/fileexchange/24589-kinematics-toolbox/content/kinematics/screws/skew.m
    if size(w,1) <>3 then
        error('vector must be 3x1')
    end

    if or(type(w)==[1 5 8]) then
        R = zeros(3,3);
    end

    R(1,2) = -w(3);
    R(1,3) =  w(2);
    R(2,3) = -w(1);

    R(2,1) =  w(3);
    R(3,1) = -w(2);
    R(3,2) =  w(1);

    //   R(1,1) = 0;
    //   R(2,2) = 0;
    //   R(3,3) = 0;

endfunction
