//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function [x, y, typ] = tr2rpy_if(job, arg1, arg2)
	// tr2rpy_if
	//
	// Description
	// Return the roll/pitch/yaw angles, in radians, corresponding to the rotational part of the homogeneous transform given as input.
	//
	// This block has one regular input.
	//
	// The number of outputs to this block is three and all outputs are regular outputs. 
	// The first output is the roll angle, the second is the pitch angle and the third output is the yaw angl
	//
	// See also
	// rpy2tr_if
	// T2eul_if
	// tr2rpy  
	//
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014 - Davide Cappucci
    
    x = [];
    y = [];
    typ = [];
	
	out_label = ['roll';'pitch';'yaw'];
	in_label = ['T']; 
	style = 'blockWithLabel;fillColor=red;displayedLabel=T2rpy;fontStyle=1;fontSize=12;align=left';
    select job,
        case "set" then
            x = arg1;
        case "define" then
            model = scicos_model();
            model.sim = list("tr2rpy_cf", 5);
            model.in = 4;
            model.in2 = 4;
            model.intyp = 1;
            model.out = [1; 1; 1];
            model.out2 = [1; 1; 1];
            model.outtyp = [1; 1; 1];
            model.blocktype = "d";
            model.dep_ut = [%T %F];
            x = standard_define([4 4], model, "", "");
			x.graphics.style = style;
			x.graphics.out_label = out_label;
			x.graphics.in_label = in_label;
    end

endfunction
