//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function T = trotz(t, varargin)
    //  Rotation about Z axis
    // 
    // Calling Sequence
    //  T = trotz(THETA)
    //  T = trotz(THETA, 'deg')
    //
    //  Description
    //  <literal>T = TROTZ(THETA)</literal> is a homogeneous transformation (4x4) representing a rotation 
    //  radians about the x-axis.
    // 
    //  <literal>T = TROTZ(THETA, 'deg')</literal> as above but THETA is in degrees.
    // 
    //  Translational component is zero.
    // 
    // See also 
    // rotz
    // trotx
    // troty
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014 - Davide Cappucci
    
    T = [rotz(t, varargin) [0 0 0]'; 0 0 0 1];
    
endfunction
