//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function [x, y, typ] = xyz2T_if(job, arg1, arg2)
	// xyz2T_if
	//
	// Description
	// Return the homogeneous transform resulting from the translation transformation.
	//
	// The number of inputs to this block is three and all inputs are regular inputs. 
	// The first input is the X-axis component, the second input is the Y-axis component and the third input is the Z-axis component of the translation vector.
	//
	// This block has one regular output.
	//
	// See also
	// tr2xyz_if
	// transl  
	//
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014 - Davide Cappucci
    
    x = [];
    y = [];
    typ = [];
    
    out_label = ['T']; 
	in_label = ['x';'y';'z'];
    style = 'blockWithLabel;fillColor=red;displayedLabel=xyz2T;fontStyle=1;fontSize=12';
  
    select job,
        case "set" then
            x = arg1;

        case "define" then
            model = scicos_model();
            model.sim = list("xyz2T_cf", 5);
            model.in = [1; 1; 1];
            model.in2 = [1; 1; 1];
            model.intyp = [1; 1; 1];
            model.out = 4;
            model.out2 = 4;
            model.outtyp = 1;
            model.blocktype = "d";
            model.dep_ut = [%T %F];
            x = standard_define([4 4], model, "", "");
            x.graphics.style = style;
	       	x.graphics.out_label = out_label;
	    	x.graphics.in_label = in_label;         
    end

endfunction
