/*		 Links			*/
#include "api_scilab.h"
#include "stdio.h"
#include "stdlib.h"
#include "vmath.h"
#include "scicos_block4.h"
#include "string.h"

#include    <math.h>
#include    "vmath.h"

#define TRUE    1
#define FALSE   0

/* Robot kinematic convention */
typedef
    enum _dhtype {
        STANDARD,
        MODIFIED
} DHType;

/* Link joint type */
typedef
    enum _axistype {
        REVOLUTE = 0,
        PRISMATIC = 1
} Sigma;

/* A robot link structure */
typedef struct _link {
    /**********************************************************
     *************** kinematic parameters *********************
     **********************************************************/
    double  alpha;      /* link twist */
    double  A;          /* link offset */
    double  D;          /* link length */
    double  theta;      /* link rotation angle */
    double  offset;     /* link coordinate offset */
    int sigma;          /* axis type; revolute or prismatic */
    int mdh;

    /**********************************************************
     ***************** dynamic parameters *********************
     **********************************************************/

    /**************** of links ********************************/
    Vect    *rbar;      /* centre of mass of link wrt link origin */
    double  m;          /* mass of link */
    double  *I;         /* inertia tensor of link wrt link origin */

    /**************** of actuators *****************************/
        /* these parameters are motor referenced */
    double  Jm;         /* actuator inertia */
    double  G;          /* gear ratio */
    double  B;          /* actuator friction damping coefficient */
    double  *Tc;        /* actuator Coulomb friction coeffient */

    /**********************************************************
     **************** intermediate variables ******************
     **********************************************************/
    Vect    r;          /* distance of ith origin from i-1th wrt ith */
    Rot R;              /* link rotation matrix */
    Vect    omega;      /* angular velocity */
    Vect    omega_d;    /* angular acceleration */
    Vect    acc;        /* acceleration */
    Vect    abar;       /* acceleration of centre of mass */
    Vect    f;          /* inter-link force */
    Vect    n;          /* inter-link moment */
} Link;

/* A robot */
typedef struct _robot {
    int njoints;    /* number of joints */
    Vect    *gravity;   /* gravity vector */
    DHType  dhtype;     /* kinematic convention */
    Link    *links;     /* the links */
} Robot;

//
//Link *create_robot_from_links(scicos_block *block);
Link *create_link(double *dh);
Link create_link_2(double *dh);
Link *cre_def_p_link();
void free_link(Link *L);
void print_Link(Link *L);
void print_full_Link(Link *L); 
Robot create_robot(Link *L,int n,double *gravity,int mdh);
void print_robot(Robot robot);
void free_robot(Robot robot);
void rot_mat(Link *l, double th, double d, DHType type);
void newton_euler(Robot *robot, double *tau, double *qd, double *qdd, double *fext, int stride);
