//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of the Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.


//TEST QUATERNION OPERATORS
// 
// Function checked:
// ==           %Quat_o_Quat,    %l_o_Quat,   %Quat_o_l;
// ~=           %Quat_n_Quat,    %l_n_Quat,   %Quat_n_l;
// +            %Quat_a_Quat;
// -            %Quat_s_Quat;
// *            %Quat_m_Quat,    %s_m_Quat;
// /            %Quat_r_Quat;
// qscale
// qinterp
//


//Create a quaternion that represents a rotation of 90 degrees about X axis
quat1 = Quaternion(%pi/2, [1,0,0]);
 
quat2 = Quaternion(%pi/2, [0,1,0]);

quat3 = Quaternion(%pi/2, [1,0,0]);

//--------------------------------------------------------------------------//
//Check function: "%Quat_o_Quat"
//--------------------------------------------------------------------------//
assert_checkfalse(quat1 == quat2);
assert_checktrue(quat1 == quat3);


//--------------------------------------------------------------------------//
//Check function: "%l_o_Quat" and "%Quat_o_l"
//--------------------------------------------------------------------------//
assert_checktrue(list(quat1,quat3) == quat1);
assert_checktrue(quat1 == list(quat1,quat3));

assert_checkfalse(list(quat1,quat3) == quat2);
assert_checkfalse(quat2 == list(quat1,quat3));


//--------------------------------------------------------------------------//
//Check function: "%Quat_n_Quat"
//--------------------------------------------------------------------------//
assert_checkfalse(quat1 ~= quat3);
assert_checktrue(quat1 ~= quat2);

//--------------------------------------------------------------------------//
//Check function: "%l_n_Quat" and "%Quat_n_l"
//--------------------------------------------------------------------------//
assert_checktrue(list(quat1,quat3) ~= quat2);
assert_checktrue(quat2 ~= list(quat1,quat3));

assert_checkfalse(list(quat1,quat3) ~= quat1);
assert_checkfalse(quat1 ~= list(quat1,quat3));


//--------------------------------------------------------------------------//
//Check function: "%Quat_a_Quat"
//--------------------------------------------------------------------------//
addQuat = quat1 + quat2;
assert_checkalmostequal(addQuat.s, 1.414214, 1.e-5);
assert_checkalmostequal(addQuat.v, [0.707107, 0.707107, 0.000000], 1.e-5);

//--------------------------------------------------------------------------//
//Check function: "%Quat_s_Quat"
//--------------------------------------------------------------------------//
subQuat = quat1 - quat2;
assert_checkequal(subQuat.s, 0);
assert_checkalmostequal(subQuat.v, [0.707107, -0.707107, 0.000000], 1.e-5);

subQuat = quat1 - quat3;
assert_checkequal(subQuat.s, 0);
assert_checkequal(subQuat.v, [0, 0, 0]);


//--------------------------------------------------------------------------//
//Check function: "%Quat_m_Quat"
//--------------------------------------------------------------------------//
prodQuat = quat1 * quat2;
assert_checkalmostequal(prodQuat.s, 0.5, 1.e-5);
assert_checkalmostequal(prodQuat.v, [0.5, 0.5, 0.5], 1.e-5);

//--------------------------------------------------------------------------//
//Check function: "%s_m_Quat"
//--------------------------------------------------------------------------//
prodQuat = 2 * quat1;
assert_checkalmostequal(prodQuat.s, 1.414214, 1.e-5);
assert_checkalmostequal(prodQuat.v, [1.414214, 0, 0], 1.e-5);

prodQuat = [1;2;3] * quat1;
assert_checkalmostequal(prodQuat,[1,-3,2], 1.e-15);

//--------------------------------------------------------------------------//
//Check function: "%Quat_r_Quat"
//--------------------------------------------------------------------------//
divQuat = quat1 / quat2;
assert_checkalmostequal(divQuat.s, 0.5, 1.e-5);
assert_checkalmostequal(divQuat.v, [0.5, -0.5, -0.5], 1.e-5);

divQuat = quat1 / quat3;
assert_checkalmostequal(divQuat.s, 1, 1.e-5);
assert_checkalmostequal(divQuat.v, [0, 0, 0], 1.e-5);

//--------------------------------------------------------------------------//
//Check function: "%Quat_r_s"
//--------------------------------------------------------------------------//
divQuat = quat1 / 2;
assert_checkalmostequal(divQuat.s, 0.353553, 1.e-5);
assert_checkalmostequal(divQuat.v, [0.353553, 0, 0], 1.e-5);

divQuat = quat1 / -3;
assert_checkalmostequal(divQuat.s, -0.235702, 1.e-5);
assert_checkalmostequal(divQuat.v, [-0.235702, 0, 0], 1.e-5);


//--------------------------------------------------------------------------//
//Check function: "%Quat_p_s"
//--------------------------------------------------------------------------//
nQuat = quat1^2;
//phyton use 'd' instead of 'e'
//assert_checkalmostequal(nQuat.s, 2.22d-16, 1.d-5);
assert_checkalmostequal(nQuat.v, [1, 0, 0], %eps);

nQuat = quat1^3;
assert_checkalmostequal(nQuat.s, -0.707107, 1.e-5);
assert_checkalmostequal(nQuat.v, [0.707107, 0, 0], 1.e-5);

nQuat = quat1^4;
assert_checkalmostequal(nQuat.s, -1, 1.e-5);
//assert_checkalmostequal(nQuat.v, [0, 0, 0], %eps);
clear quat1 quat2 quat3 prodQuat addQuat subQuat divQuat nQuat
